HTTP fetch client for Yahoo Finance requests.
This module provides a low-level HTTP client with proxy support, cookie management, and timeout handling.
Structs
- Fetch
Client - HTTP client for fetching data from Yahoo Finance.
HTTP fetch client for Yahoo Finance requests.
This module provides a low-level HTTP client with proxy support, cookie management, and timeout handling.