Index

Enum Index 

pub enum Index {
Show 73 variants Gspc, Dji, Ixic, Nya, Xax, Rut, Vix, Gsptse, Bvsp, Mxx, Ipsa, Merv, Ivbx, Ibrx50, Ftse, Gdaxi, Fchi, Stoxx50e, N100, Bfx, MoexMe, Aex, Ibex, Ftsemib, Ssmi, Psi, Atx, Omxs30, Omxc25, Wig20, Bux, Imoex, Rtsi, Hsi, Sti, Bsesn, Jkse, Klse, Ks11, Twii, N225, Shanghai, Szse, Set, Nsei, Cnx200, Psei, ChinaA50, Djsh, Indiavix, Case30, Jn0uJo, Ftsejse, Afr40, Raf40, Sa40, Alt15, Ta125Ta, Ta35, Tasi, Tamayuz, Bist100, Axjo, Aord, Nz50, DxYNyb, UsdStrd, Xdb, Xde, Xdn, Xda, MsciWorld, Buk100p,
}

Variants



Gspc



Dji



Ixic



Nya



Xax



Rut



Vix



Gsptse



Bvsp



Mxx



Ipsa



Merv



Ivbx



Ibrx50



Ftse



Gdaxi



Fchi



Stoxx50e



N100



Bfx



MoexMe



Aex



Ibex



Ftsemib



Ssmi



Psi



Atx



Omxs30



Omxc25



Wig20



Bux



Imoex



Rtsi



Hsi



Sti



Bsesn



Jkse



Klse



Ks11



Twii



N225



Shanghai



Szse



Set



Nsei



Cnx200



Psei



ChinaA50



Djsh



Indiavix



Case30



Jn0uJo



Ftsejse



Afr40



Raf40



Sa40



Alt15



Ta125Ta



Ta35



Tasi



Tamayuz



Bist100



Axjo



Aord



Nz50



DxYNyb



UsdStrd



Xdb



Xde



Xdn



Xda



MsciWorld



Buk100p

Implementations

Source

impl Index

pub fn as_str(&self) -> &'static str

pub fn parse(s: &str) -> Option<Self>

pub fn all() -> Vec<Index>