Streaming functionality for real-time data.
This module provides async streams for continuously fetching financial data at configurable intervals. These streams can be used with any async runtime and integrated into WebSocket servers or other streaming applications.
Structs
- Index
Stream - A stream that yields market index updates at regular intervals.
- Movers
Stream - A stream that yields market movers (actives, gainers, losers) at regular intervals.
- Quote
Stream - A stream that yields quote updates at regular intervals.
- Single
Quote Stream - A stream that yields a single quote update for one symbol.